Tungsten
========

Tungsten is an add-on for [Lightbulb](https://github.com/tandemdude/hikari-lightbulb) providing an alternative for handling component interactions.
Using coordinates and indexes, this library supplies the flexibility to edit buttons and options on the run.

- **License:** [LGPLv3](https://choosealicense.com/licenses/lgpl-3.0/)

- **Repository:** [GitHub](https://github.com/Christian-Tarello/lightbulb-ext-tungsten)

- **Documentation:** [ReadTheDocs](https://lightbulb-tungsten.readthedocs.io/en/latest/)

Installation
------------

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Tungsten.

```bash
pip install lightbulb-ext-tungsten
```

Contributions & Issues
----------------------

If you find a bug, unexpected behaviour or want to suggest a feature to this library, 
submit an issue on the GitHub repository [here](https://github.com/Christian-Tarello/lightbulb-ext-tungsten/issues). 
Make sure you are on the latest version of the library and the issue has not been suggested yet.
